import React,{ useState, useEffect, } from 'react'
import {
  Card,
  TreeSelect,
  Space,
  Button,
  Table,
  Input,
  Row, 
  Col
} from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { connect } from 'react-redux';
import TestModal from './ModalComponent';
import ListCard from './ListCard';
import { get, post } from '../../services';

const { Search } = Input
const { TreeNode } = TreeSelect;
const treeData = [
  {
    title: 'Node1',
    value: '0-0',
    children: [
      {
        title: 'Child Node1',
        value: '0-0-1',
      },
      {
        title: 'Child Node2',
        value: '0-0-2',
      },
    ],
  },
  {
    title: 'Node2',
    value: '0-1',
  },
];


const DefaultComponent = ()=> {
  const [treeValue, setTreeValue] = useState(null)//树节点选中的值
  const [tableData, setTableData] = useState([]) //table的值
  const [selectedRowKeys, setSelectedRowKeys] = useState([]) //table表格checkbox配置
  const [modalVisible, setModalVisible] = useState(false) //展示Modal弹窗
  const [modalVisible2, setModalVisible2] = useState(false) //展示Modal弹窗
  const [testPeoList, setTestPeoList] = useState([]) //测试card数组
  //树节点选中的值
  const treeChange = (e) =>{
    setTreeValue(e)
  }
  //用户搜索
  const handleSearch = ()=>{
    console.log('handleSearch')
    setModalVisible(true)
  }
  //导入
  const handleImport = () =>{
    setModalVisible(true)
  }
  //搜索框时间
  const inputSearch = (e) =>{
    console.log(e,'inputSearch')
  }
  const columns = [
    {
      title:'用户ID',
      dataIndex:"userID",
      key:'userID'
    },
    {
      title:'登录名',
      dataIndex:'loginName',
      key:'loginName'
    },
    {
      title:'用户姓名',
      dataIndex:'userName',
      key:'userName',
    },
    {
      title:'手机号码',
      dataIndex:'phone',
      key:'phone'
    },
    {
      title:'钉钉账户',
      dataIndex:'ddid',
      key:'ddid',
    },
    {
      title:'微信账户',
      dataIndex:'wxid',
      key:'wxid'
    }
  ]
  useEffect( () =>{
    get('/Cityinterface/rest/services/OMS.svc/U_GetOneOUUserListNew',{
      OUID:24,
      _version:9999,
      _dc:new Date().getTime()
    }).then(res =>{
      if(res.success){
        setTableData(res.root)
      }
      console.log(res)
    })
    const testData =[]
    const test2list = []
    for( let i=1; i<10 ; i++){
      testData.push({
        key:i,
        ID:i
      })
      test2list.push({
        label:i+"测试",
        value:i+"测试",
      })
    }
    console.log(test2list)

    setTestPeoList(test2list)
  },[])
   //table选中框的值
   const selectChange = (e) =>{
    console.log(e,'e')
    setSelectedRowKeys(e)
  }
  const confirmModal = () =>{
    setModalVisible(false)
  }
  //table复选的配置
  const rowSelection ={
    selectedRowKeys,
    onChange:selectChange,
  }
  const btnLable = [
    {label:'查找用户',handle:handleSearch},
    {label:'用户导入',handle:handleImport},
    {label:'新建用户',handle:'newHandle'},
    {label:'批量关联',handle:'relHandle'}
  ]

  return (
    <>
      <PageContainer>
        <Card>
          <Row>
            机构选择
            <Col span={12}>
            <TreeSelect
              style={{"width":"50%"}}
              treeData={treeData}
              value={treeValue}
              onChange={ (e) => { treeChange(e)}}
            />
            </Col>
            <Col span={ 8}>
            <Search 
            placeholder="请输入" 
            onSearch={(e) =>{inputSearch(e)}} 
            style={{ width: "50%" }} 
            enterButton 
            />
            </Col>
          </Row>
        </Card>
        <Card>
          <Space>
            {
              btnLable && btnLable.map( (item,index) => {
                return (
                   <Button key={index} onClick ={  ()=>{ item.handle && typeof item.handle === 'function' && item.handle()}}>{item.label}</Button>
                )
              })
            }
          </Space>
          <TestModal
            title='测试title'
            visible = {modalVisible}
            maskClosable
            onOk={() => confirmModal()}
            onCancel={() => setModalVisible(false)}
            bodyStyle ={{width:"100%",height:"100%",}}
            style= {{top:20}}
            width="1000px"
            destroyOnClose={true}
          >
            <ListCard optionsList ={testPeoList}></ListCard>
          </TestModal>
        </Card>
        <Card>
          <div>一般用户的用户列表</div>
          <Table 
          rowSelection={rowSelection} 
          columns={columns} 
          dataSource ={tableData} 
          bordered
          rowKey='userID'
          ></Table>
        </Card>
      </PageContainer>
    </>
  )
}

export default connect()(DefaultComponent)